@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     authlib.oauth2.rfc7662
     ~~~~~~~~~~~~~~~~~~~~~~
@@ -11,5 +10,6 @@
 
 from .introspection import IntrospectionEndpoint
 from .models import IntrospectionToken
+from .token_validator import IntrospectTokenValidator
 
-__all__ = ['IntrospectionEndpoint', 'IntrospectionToken']
+__all__ = ['IntrospectionEndpoint', 'IntrospectionToken', 'IntrospectTokenValidator']
